# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: supabase_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'supabase_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16supabase_service.proto\x12\x0cisa.supabase\x1a\x0c\x63ommon.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xa9\x01\n\x0cQueryRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0e\n\x06select\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\r\n\x05order\x18\x05 \x01(\t\x12\r\n\x05limit\x18\x06 \x01(\x05\x12\x0e\n\x06offset\x18\x07 \x01(\x05\x12\r\n\x05\x63ount\x18\x08 \x01(\x08\"u\n\rQueryResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"\x89\x01\n\rInsertRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0breturn_data\x18\x04 \x01(\x08\"v\n\x0eInsertResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"\x99\x01\n\rUpdateRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\x13\n\x0breturn_data\x18\x05 \x01(\x08\"v\n\x0eUpdateResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"r\n\rDeleteRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x13\n\x0breturn_data\x18\x04 \x01(\x08\"v\n\x0e\x44\x65leteResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"\x9e\x01\n\rUpsertRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bon_conflict\x18\x04 \x01(\t\x12\x13\n\x0breturn_data\x18\x05 \x01(\x08\"v\n\x0eUpsertResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12%\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\"{\n\nRPCRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\x15\n\rfunction_name\x18\x02 \x01(\t\x12\'\n\x06params\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"c\n\x0bRPCResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12$\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value\"\xa5\x01\n\x16UpsertEmbeddingRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x11\n\tembedding\x18\x04 \x03(\x02\x12.\n\rmetadata_json\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"f\n\x17UpsertEmbeddingResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07success\x18\x03 \x01(\x08\"\xb2\x01\n\x17SimilaritySearchRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x17\n\x0fquery_embedding\x18\x03 \x03(\x02\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\t\x12\x0e\n\x06metric\x18\x06 \x01(\t\x12\x11\n\tthreshold\x18\x07 \x01(\x02\"}\n\x18SimilaritySearchResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x31\n\x07results\x18\x02 \x03(\x0b\x32 .isa.supabase.VectorSearchResult\"_\n\x12VectorSearchResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsimilarity\x18\x02 \x01(\x02\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xc8\x01\n\x13HybridSearchRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\x12\n\ntext_query\x18\x03 \x01(\t\x12\x14\n\x0cvector_query\x18\x04 \x03(\x02\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x13\n\x0btext_weight\x18\x06 \x01(\x02\x12\x15\n\rvector_weight\x18\x07 \x01(\x02\x12\x0e\n\x06\x66ilter\x18\x08 \x01(\t\"y\n\x14HybridSearchResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x31\n\x07results\x18\x02 \x03(\x0b\x32 .isa.supabase.VectorSearchResult\"b\n\x16\x44\x65leteEmbeddingRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"Z\n\x17\x44\x65leteEmbeddingResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07success\x18\x02 \x01(\x08\"\x8d\x01\n\x12\x42\x61tchInsertRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nbatch_size\x18\x04 \x01(\x05\"\x96\x01\n\x13\x42\x61tchInsertResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x15\n\rsuccess_count\x18\x03 \x01(\x05\x12\x13\n\x0b\x65rror_count\x18\x04 \x01(\x05\x12\x0e\n\x06\x65rrors\x18\x05 \x03(\t\"\x8d\x01\n\x1c\x42\x61tchUpsertEmbeddingsRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\x12\r\n\x05table\x18\x02 \x01(\t\x12/\n\nembeddings\x18\x03 \x03(\x0b\x32\x1b.isa.supabase.EmbeddingData\"Y\n\rEmbeddingData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tembedding\x18\x02 \x03(\x02\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xa0\x01\n\x1d\x42\x61tchUpsertEmbeddingsResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x15\n\rsuccess_count\x18\x03 \x01(\x05\x12\x13\n\x0b\x65rror_count\x18\x04 \x01(\x05\x12\x0e\n\x06\x65rrors\x18\x05 \x03(\t\"C\n\x12HealthCheckRequest\x12-\n\x08metadata\x18\x01 \x01(\x0b\x32\x1b.isa.common.RequestMetadata\"\xa3\x01\n\x13HealthCheckResponse\x12.\n\x08metadata\x18\x01 \x01(\x0b\x32\x1c.isa.common.ResponseMetadata\x12\x0f\n\x07healthy\x18\x02 \x01(\x08\x12\x17\n\x0fsupabase_status\x18\x03 \x01(\t\x12\x18\n\x10postgres_version\x18\x04 \x01(\t\x12\x18\n\x10pgvector_enabled\x18\x05 \x01(\x08\x32\xbe\x08\n\x0fSupabaseService\x12@\n\x05Query\x12\x1a.isa.supabase.QueryRequest\x1a\x1b.isa.supabase.QueryResponse\x12\x43\n\x06Insert\x12\x1b.isa.supabase.InsertRequest\x1a\x1c.isa.supabase.InsertResponse\x12\x43\n\x06Update\x12\x1b.isa.supabase.UpdateRequest\x1a\x1c.isa.supabase.UpdateResponse\x12\x43\n\x06\x44\x65lete\x12\x1b.isa.supabase.DeleteRequest\x1a\x1c.isa.supabase.DeleteResponse\x12\x43\n\x06Upsert\x12\x1b.isa.supabase.UpsertRequest\x1a\x1c.isa.supabase.UpsertResponse\x12\x41\n\nExecuteRPC\x12\x18.isa.supabase.RPCRequest\x1a\x19.isa.supabase.RPCResponse\x12^\n\x0fUpsertEmbedding\x12$.isa.supabase.UpsertEmbeddingRequest\x1a%.isa.supabase.UpsertEmbeddingResponse\x12\x61\n\x10SimilaritySearch\x12%.isa.supabase.SimilaritySearchRequest\x1a&.isa.supabase.SimilaritySearchResponse\x12U\n\x0cHybridSearch\x12!.isa.supabase.HybridSearchRequest\x1a\".isa.supabase.HybridSearchResponse\x12^\n\x0f\x44\x65leteEmbedding\x12$.isa.supabase.DeleteEmbeddingRequest\x1a%.isa.supabase.DeleteEmbeddingResponse\x12R\n\x0b\x42\x61tchInsert\x12 .isa.supabase.BatchInsertRequest\x1a!.isa.supabase.BatchInsertResponse\x12p\n\x15\x42\x61tchUpsertEmbeddings\x12*.isa.supabase.BatchUpsertEmbeddingsRequest\x1a+.isa.supabase.BatchUpsertEmbeddingsResponse\x12R\n\x0bHealthCheck\x12 .isa.supabase.HealthCheckRequest\x1a!.isa.supabase.HealthCheckResponseB3Z1github.com/isa-cloud/isa_cloud/api/proto/supabaseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'supabase_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/isa-cloud/isa_cloud/api/proto/supabase'
  _globals['_QUERYREQUEST']._serialized_start=118
  _globals['_QUERYREQUEST']._serialized_end=287
  _globals['_QUERYRESPONSE']._serialized_start=289
  _globals['_QUERYRESPONSE']._serialized_end=406
  _globals['_INSERTREQUEST']._serialized_start=409
  _globals['_INSERTREQUEST']._serialized_end=546
  _globals['_INSERTRESPONSE']._serialized_start=548
  _globals['_INSERTRESPONSE']._serialized_end=666
  _globals['_UPDATEREQUEST']._serialized_start=669
  _globals['_UPDATEREQUEST']._serialized_end=822
  _globals['_UPDATERESPONSE']._serialized_start=824
  _globals['_UPDATERESPONSE']._serialized_end=942
  _globals['_DELETEREQUEST']._serialized_start=944
  _globals['_DELETEREQUEST']._serialized_end=1058
  _globals['_DELETERESPONSE']._serialized_start=1060
  _globals['_DELETERESPONSE']._serialized_end=1178
  _globals['_UPSERTREQUEST']._serialized_start=1181
  _globals['_UPSERTREQUEST']._serialized_end=1339
  _globals['_UPSERTRESPONSE']._serialized_start=1341
  _globals['_UPSERTRESPONSE']._serialized_end=1459
  _globals['_RPCREQUEST']._serialized_start=1461
  _globals['_RPCREQUEST']._serialized_end=1584
  _globals['_RPCRESPONSE']._serialized_start=1586
  _globals['_RPCRESPONSE']._serialized_end=1685
  _globals['_UPSERTEMBEDDINGREQUEST']._serialized_start=1688
  _globals['_UPSERTEMBEDDINGREQUEST']._serialized_end=1853
  _globals['_UPSERTEMBEDDINGRESPONSE']._serialized_start=1855
  _globals['_UPSERTEMBEDDINGRESPONSE']._serialized_end=1957
  _globals['_SIMILARITYSEARCHREQUEST']._serialized_start=1960
  _globals['_SIMILARITYSEARCHREQUEST']._serialized_end=2138
  _globals['_SIMILARITYSEARCHRESPONSE']._serialized_start=2140
  _globals['_SIMILARITYSEARCHRESPONSE']._serialized_end=2265
  _globals['_VECTORSEARCHRESULT']._serialized_start=2267
  _globals['_VECTORSEARCHRESULT']._serialized_end=2362
  _globals['_HYBRIDSEARCHREQUEST']._serialized_start=2365
  _globals['_HYBRIDSEARCHREQUEST']._serialized_end=2565
  _globals['_HYBRIDSEARCHRESPONSE']._serialized_start=2567
  _globals['_HYBRIDSEARCHRESPONSE']._serialized_end=2688
  _globals['_DELETEEMBEDDINGREQUEST']._serialized_start=2690
  _globals['_DELETEEMBEDDINGREQUEST']._serialized_end=2788
  _globals['_DELETEEMBEDDINGRESPONSE']._serialized_start=2790
  _globals['_DELETEEMBEDDINGRESPONSE']._serialized_end=2880
  _globals['_BATCHINSERTREQUEST']._serialized_start=2883
  _globals['_BATCHINSERTREQUEST']._serialized_end=3024
  _globals['_BATCHINSERTRESPONSE']._serialized_start=3027
  _globals['_BATCHINSERTRESPONSE']._serialized_end=3177
  _globals['_BATCHUPSERTEMBEDDINGSREQUEST']._serialized_start=3180
  _globals['_BATCHUPSERTEMBEDDINGSREQUEST']._serialized_end=3321
  _globals['_EMBEDDINGDATA']._serialized_start=3323
  _globals['_EMBEDDINGDATA']._serialized_end=3412
  _globals['_BATCHUPSERTEMBEDDINGSRESPONSE']._serialized_start=3415
  _globals['_BATCHUPSERTEMBEDDINGSRESPONSE']._serialized_end=3575
  _globals['_HEALTHCHECKREQUEST']._serialized_start=3577
  _globals['_HEALTHCHECKREQUEST']._serialized_end=3644
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=3647
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=3810
  _globals['_SUPABASESERVICE']._serialized_start=3813
  _globals['_SUPABASESERVICE']._serialized_end=4899
# @@protoc_insertion_point(module_scope)
